-- RShamanStat UI Code
--
-- handles all UI specific events
--


local revision = tonumber(string.sub("$Revision: 46 $", 12, -3))
local rss = _G.RShamanStat
if rss.revision < revision then rss.revision = revision end


local encounterFilter = "";
local selectedIndex = 0;
local selectedButton = nil;

function SetEncounterFilter(filter)
    encounterFilter = filter

    if selectedButton then
        selectedIndex = 0;
        selectedButton.selectedTex:Hide();
        selectedButton = nil;
    end

    RShamanStatUI_UpdateRecordList()
end

function RShamanStatUI_OnTextChanged(self)
    local text = self:GetText();

    if ( text == SEARCH ) then
        SetEncounterFilter("");
        return;
    end

    SetEncounterFilter(text);
end

function RShamanStatUI_Load()
    RShamanStatFrame.TitleText:SetText("Resto Shaman Stat Analysis");
    RShamanStatFrameScrollFrame.update = RShamanStatUI_UpdateRecordList;
    HybridScrollFrame_CreateButtons(RShamanStatFrameScrollFrame, "RShamanStatFrameRecordButtonTemplate", 0, -1, "TOPLEFT", "TOPLEFT", 0, -1, "TOP", "BOTTOM");
    rss.UpdateUI = RShamanStatUI_UpdateRecordList;
end

function RShamanStatUI_OnClickSummary()
    local archive = RShamanStatUI_GetFilteredArchive();
    local record =  rss.CreateAggregateRecord("Summary", archive, function(r) return true; end)
    RShamanStatFrameRecordInfo.header:SetText("Summary for Search: '" .. encounterFilter .."'");
    RShamanStatFrameRecordInfo.content:SetText(rss.RecordToString(record));
end

function RShamanStatUI_OnClickRecord(self, button)
    if self == selectedButton then
        return;
    end

    if selectedButton then
        selectedButton.selectedTex:Hide();
    end

    selectedIndex = self.recordIndex;
    selectedButton = self;
    selectedButton.selectedTex:Show();

    PlaySound("INTERFACESOUND_CHARWINDOWTAB");

    local archive = RShamanStatUI_GetFilteredArchive();
    local record = archive[selectedIndex];
    RShamanStatFrameRecordInfo.header:SetText(record.encounterName);
    RShamanStatFrameRecordInfo.content:SetText(rss.RecordToString(record));

end

function RShamanStatUI_GetFilteredArchive()
    local archive = {};
    local numRecords = 0;
    for i,rec in ipairs(RShamanStatArchive) do
        if encounterFilter == "" or strfind(string.lower(rec.encounterName), string.lower(encounterFilter)) then
            archive[numRecords+1] = rec;
            numRecords = numRecords + 1;
        end
    end
    return archive
end

function RShamanStatUI_UpdateRecordList()
    local archive = RShamanStatUI_GetFilteredArchive();
    local numRecords = #archive;

    local scrollFrame = RShamanStatFrame.scrollFrame;
    local buttons = scrollFrame.buttons;
    local numButtons = #buttons;

    if selectedButton then
        selectedButton.selectedTex:Hide();
    end

    for i = 1, numButtons do
        local button = buttons[i];
        local offset = HybridScrollFrame_GetOffset(scrollFrame);
        local index = i + offset;
        if index <= numRecords then
            button:Show();
            button.encounter:SetText(index .. ". " .. archive[index].encounterName);
            button.date:SetText(date("%c", archive[index].startTime));
            button.recordIndex = index;
            if selectedIndex == index then
                selectedButton = button;
                selectedButton.selectedTex:Show();
            end
        else
            button:Hide();
        end
    end

    HybridScrollFrame_Update(scrollFrame, 41*(numRecords)+5, 330);
end